# sebaubuntu_libs

[![PyPi version](https://img.shields.io/pypi/v/sebaubuntu_libs)](https://pypi.org/project/sebaubuntu_libs/)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/383072c93d5b4fa293237d42360e2170)](https://www.codacy.com/gh/SebaUbuntu/sebaubuntu_libs/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=SebaUbuntu/sebaubuntu_libs&amp;utm_campaign=Badge_Grade)

A collection of code shared between my projects
